==> jhdf_2.6.1.orig.tar.gz: jhdf-2.6.1/ncsa/hdf/hdf5lib/exceptions/HDF5DataspaceInterfaceException.java <==
/****************************************************************************
 * NCSA HDF5                                                                 *
 * National Comptational Science Alliance                                   *
 * University of Illinois at Urbana-Champaign                               *
 * 605 E. Springfield, Champaign IL 61820                                   *
 *                                                                          *
 * For conditions of distribution and use, see the accompanying             *
 * hdf-java/COPYING file.                                                  *
 *                                                                          *
 ****************************************************************************/

package ncsa.hdf.hdf5lib.exceptions;


/**
 *  The class HDF5LibraryException returns errors raised by the HDF5
 *  library.
 *  <p>
 *  This sub-class represents HDF-5 major error code
 *       <b>H5E_DATASPACE</b>
 */

public class HDF5DataspaceInterfaceException extends HDF5LibraryException 
{
    /**
     * Constructs an <code>HDF5DataspaceInterfaceException</code> with
     * no specified detail message.
     */
    public HDF5DataspaceInterfaceException() {
        super();
    }

    /**
     * Constructs an <code>HDF5DataspaceInterfaceException</code> with
     * the specified detail message.
     *
     * @param   s   the detail message.
     */
    public HDF5DataspaceInterfaceException(String s) {
        super(s);
    }
}

==> jhdf_2.9.orig.tar.gz: jhdf-2.9/ncsa/hdf/hdf5lib/exceptions/HDF5DataspaceInterfaceException.java <==
/****************************************************************************
 * NCSA HDF5                                                                 *
 * National Comptational Science Alliance                                   *
 * University of Illinois at Urbana-Champaign                               *
 * 605 E. Springfield, Champaign IL 61820                                   *
 *                                                                          *
 * For conditions of distribution and use, see the accompanying             *
 * hdf-java/COPYING file.                                                  *
 *                                                                          *
 ****************************************************************************/

package ncsa.hdf.hdf5lib.exceptions;

/**
 * The class HDF5LibraryException returns errors raised by the HDF5 library.
 * <p>
 * This sub-class represents HDF-5 major error code <b>H5E_DATASPACE</b>
 */

public class HDF5DataspaceInterfaceException extends HDF5LibraryException {
    /**
     * Constructs an <code>HDF5DataspaceInterfaceException</code> with no
     * specified detail message.
     */
    public HDF5DataspaceInterfaceException() {
        super();
    }

    /**
     * Constructs an <code>HDF5DataspaceInterfaceException</code> with the
     * specified detail message.
     * 
     * @param s
     *            the detail message.
     */
    public HDF5DataspaceInterfaceException(String s) {
        super(s);
    }
}
